@@ -17,14 +17,26 @@
 
 #include <unistd.h>
 
+/*
+ * pg16 removed the configure probe for getrusage. Simply define it for all
+ * platforms except Windows to keep existing code backward compatible.
+ */
+#if PG_VERSION_NUM >= 160000
+#ifndef WIN32
+#define HAVE_GETRUSAGE
+#endif		/* HAVE_GETRUSAGE */
+#endif		/* pg16+ */
+
+#if PG_VERSION_NUM < 160000
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/time.h>
 #include <sys/resource.h>
-#endif
+#endif		/* HAVE_SYS_RESOURCE_H */
 
 #ifndef HAVE_GETRUSAGE
 #include "rusagestub.h"
-#endif
+#endif		/* !HAVE_GETRUSAGE */
+#endif		/* pg16- */
 
 #include "access/hash.h"
 #if PG_VERSION_NUM >= 90600
@@ -48,6 +60,9 @@
 #include "storage/spin.h"
 #include "utils/builtins.h"
 #include "utils/guc.h"
+#if PG_VERSION_NUM >= 160000
+#include "utils/pg_rusage.h"
+#endif
 
 #include "pg_stat_kcache.h"
 
@@ -180,9 +195,9 @@ static const struct config_enum_entry pgs_track_options[] =
 	{NULL, 0, false}
 };
 
-static int	pgsk_track;			/* tracking level */
+static int	pgsk_track = PGSK_TRACK_TOP;	/* tracking level */
 #if PG_VERSION_NUM >= 130000
-static bool pgsk_track_planning;	/* whether to track planning duration */
+static bool pgsk_track_planning = false;	/* whether to track planning duration */
 #endif
 
 #define pgsk_enabled(level) \
@@ -255,7 +270,7 @@ static Size pgsk_queryids_array_size(void);
 static void pgsk_set_queryid(pgsk_queryid queryid);
 #endif
 
-static int	pgsk_linux_hz;
+static int	pgsk_linux_hz = 0;
 
 void
 _PG_init(void)
